This function ensures S and F matrices are properly formatted and ordered for the simulated annealing function.
Source:R/Matrix_checks.R
Matrix_checks.RdSome checks applied:
drops columns with 0 values
drops taxa with missing major pigments, which are indicated with a '2'
drops pigments with < 1% in samples